import unittest
from core.gitCommands import GitCommand as gc


class Test(unittest.TestCase):

    def testExecuteCommand(self):
        print("hello")

    if __name__ == '__main__':
        unittest.main()



import subprocess as sp


class GitCommand:

    @staticmethod
    def executeCommand(self, cmd):
        proc = sp.Popen(cmd, shell=True, stdin=sp.PIPE, stdout=sp.PIPE, stderr=sp.STDOUT)
        output = proc.communicate()[0]
        return output

    @staticmethod
    def commit(self, msg=None):
        output = None
        if msg is None:
            output = self.executeCommand('git commit')
        else:
            output = self.executeCommand('git commit -m '+msg)
        return output

    @staticmethod
    def push(self, branch=None):
        output = None
        if branch is None:
            output = self.executeCommand('git push -f')
        else:
            output = self.executeCommand('git push origin '+branch)
        return output

    @staticmethod
    def status(self):
        return self.executeCommand('git status')

    @staticmethod
    def pull(self):
        return self.executeCommand('git pull')

    @staticmethod
    def branch(self):
        return self.executeCommand('git branch')

    @staticmethod
    def checkout(self, branch):
        return self.executeCommand('git checkout '+branch)

    @staticmethod
    def branchAll(self):
        return self.executeCommand('git branch -a')

    @staticmethod
    def createBranch(self, branch):
        return self.executeCommand('git checkout -b '+branch)

    @staticmethod
    def fetch(self):
        return self.executeCommand('git fetch')

    @staticmethod
    def currentBranch(self):
        return self.executeCommand('git rev-parse --abbrev-ref HEAD')


import os
import shutil
from setuptools import Command


class CleanCommand(Command):

    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        print("Running clean")
        shutil.rmtree("./build", ignore_errors=True)
        shutil.rmtree("./dist", ignore_errors=True)
        print("Completed clean up")



from setuptools import Command
from subprocess import Popen
import sys


class ReleaseCommand(Command):
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def build(self):

        """
        Build a wheel distribution.
        """
        code = Popen([sys.executable, "setup.py", "clean", "sdist"]).wait()
        if code:
            raise RuntimeError("Error building wheel")

    def publish(self):
        """
        Publish the distribution to local PyPi.
        """
        process = Popen(["twine", "upload", "-u" , "Rainmakers","-p", "Junkyfunky8990#", "dist/*"])

    def run(self):
        print("Running Build")
        self.build()
        print("Completed Build")
        print("Running release")
        self.publish()
        print("Completed release")



import setuptools
from core.clean import CleanCommand
from core.release import ReleaseCommand

# with open("README.md", "r") as fh:
#    long_description = fh.read()

setuptools.setup(
    name="fw-py-core",
    version="0.0.1",
    author="rainmakers",
    author_email="rainmakers9090@gmail.com",
    description="Python core library'",
    long_description_content_type="text/markdown",
    # url="https://github.com",
    packages=setuptools.find_packages(exclude=["tests"]),
    cmdclass={"clean": CleanCommand , "release": ReleaseCommand},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)
